@@ -459,7 +459,7 @@ extern struct PlayerInfo	stored_player[], *local_player;
 #endif
 extern struct HiScore		highscore[];
 extern struct TapeInfo		tape;
-extern struct JoystickInfo	joystick[];
+//extern struct JoystickInfo	joystick[];
 extern struct SetupInfo		setup;
 extern struct GameInfo		game;
 extern struct LaserInfo		laser;
@@ -1329,8 +1329,8 @@ extern int		num_element_info;
 
 #define PROGRAM_VERSION_MAJOR	2
 #define PROGRAM_VERSION_MINOR	0
-#define PROGRAM_VERSION_PATCH	1
-#define PROGRAM_VERSION_STRING	"2.0.1"
+#define PROGRAM_VERSION_PATCH	2
+#define PROGRAM_VERSION_STRING	"2.0.2"
 
 #define PROGRAM_TITLE_STRING	"Mirror Magic II"
 #define PROGRAM_AUTHOR_STRING	"Holger Schemel"
